==> duckdb_0.3.2-2.tar.gz: duckdb/src/duckdb/amalgamation-10.cpp <==
#include "src/main/prepared_statement.cpp"

#include "src/main/prepared_statement_data.cpp"

#include "src/main/query_profiler.cpp"

#include "src/main/query_result.cpp"

#include "src/main/relation.cpp"

#include "src/main/relation/aggregate_relation.cpp"

#include "src/main/relation/create_table_relation.cpp"

#include "src/main/relation/create_view_relation.cpp"

#include "src/main/relation/cross_product_relation.cpp"

#include "src/main/relation/delete_relation.cpp"

#include "src/main/relation/distinct_relation.cpp"

#include "src/main/relation/explain_relation.cpp"

#include "src/main/relation/filter_relation.cpp"

#include "src/main/relation/insert_relation.cpp"

#include "src/main/relation/join_relation.cpp"

#include "src/main/relation/limit_relation.cpp"

#include "src/main/relation/order_relation.cpp"

#include "src/main/relation/projection_relation.cpp"

#include "src/main/relation/query_relation.cpp"

#include "src/main/relation/read_csv_relation.cpp"

#include "src/main/relation/setop_relation.cpp"

#include "src/main/relation/subquery_relation.cpp"

#include "src/main/relation/table_function_relation.cpp"

#include "src/main/relation/table_relation.cpp"

#include "src/main/relation/update_relation.cpp"

#include "src/main/relation/value_relation.cpp"

#include "src/main/relation/view_relation.cpp"

#include "src/main/relation/write_csv_relation.cpp"

#include "src/main/settings/settings.cpp"

#include "src/main/stream_query_result.cpp"

#include "src/optimizer/column_lifetime_analyzer.cpp"

#include "src/optimizer/common_aggregate_optimizer.cpp"

#include "src/optimizer/cse_optimizer.cpp"

#include "src/optimizer/deliminator.cpp"

#include "src/optimizer/expression_heuristics.cpp"

#include "src/optimizer/expression_rewriter.cpp"

#include "src/optimizer/filter_combiner.cpp"

#include "src/optimizer/filter_pullup.cpp"

#include "src/optimizer/filter_pushdown.cpp"

#include "src/optimizer/in_clause_rewriter.cpp"

#include "src/optimizer/join_order/join_relation_set.cpp"

#include "src/optimizer/join_order/query_graph.cpp"

#include "src/optimizer/join_order_optimizer.cpp"

#include "src/optimizer/matcher/expression_matcher.cpp"

#include "src/optimizer/optimizer.cpp"

#include "src/optimizer/pullup/pullup_both_side.cpp"

==> duckdb_0.3.4.tar.gz: duckdb/src/duckdb/amalgamation-10.cpp <==
#include "src/main/extension/extension_helper.cpp"

#include "src/main/extension/extension_install.cpp"

#include "src/main/extension/extension_load.cpp"

#include "src/main/materialized_query_result.cpp"

#include "src/main/pending_query_result.cpp"

#include "src/main/prepared_statement.cpp"

#include "src/main/prepared_statement_data.cpp"

#include "src/main/query_profiler.cpp"

#include "src/main/query_result.cpp"

#include "src/main/relation.cpp"

#include "src/main/relation/aggregate_relation.cpp"

#include "src/main/relation/create_table_relation.cpp"

#include "src/main/relation/create_view_relation.cpp"

#include "src/main/relation/cross_product_relation.cpp"

#include "src/main/relation/delete_relation.cpp"

#include "src/main/relation/distinct_relation.cpp"

#include "src/main/relation/explain_relation.cpp"

#include "src/main/relation/filter_relation.cpp"

#include "src/main/relation/insert_relation.cpp"

#include "src/main/relation/join_relation.cpp"

#include "src/main/relation/limit_relation.cpp"

#include "src/main/relation/order_relation.cpp"

#include "src/main/relation/projection_relation.cpp"

#include "src/main/relation/query_relation.cpp"

#include "src/main/relation/read_csv_relation.cpp"

#include "src/main/relation/setop_relation.cpp"

#include "src/main/relation/subquery_relation.cpp"

#include "src/main/relation/table_function_relation.cpp"

#include "src/main/relation/table_relation.cpp"

#include "src/main/relation/update_relation.cpp"

#include "src/main/relation/value_relation.cpp"

#include "src/main/relation/view_relation.cpp"

#include "src/main/relation/write_csv_relation.cpp"

#include "src/main/settings/settings.cpp"

#include "src/main/stream_query_result.cpp"

#include "src/optimizer/column_lifetime_analyzer.cpp"

#include "src/optimizer/common_aggregate_optimizer.cpp"

#include "src/optimizer/cse_optimizer.cpp"

#include "src/optimizer/deliminator.cpp"

#include "src/optimizer/expression_heuristics.cpp"

#include "src/optimizer/expression_rewriter.cpp"

#include "src/optimizer/filter_combiner.cpp"

#include "src/optimizer/filter_pullup.cpp"

#include "src/optimizer/filter_pushdown.cpp"

#include "src/optimizer/in_clause_rewriter.cpp"

#include "src/optimizer/join_order/join_relation_set.cpp"

#include "src/optimizer/join_order/query_graph.cpp"
